@@ -290,11 +290,11 @@ class OAuthRemoteApp(object):
 
     def _get_property(self, key, default=False):
         attr = getattr(self, '_%s' % key)
-        if attr:
+        if attr is not None:
             return attr
-        if default is not False and not self.app_key:
-            # since it has no app_key, use the original property
-            # YES, it is `attr`, not default
+        if not self.app_key:
+            if default is not False:
+                return default
             return attr
         app = self.oauth.app or current_app
         config = app.config[self.app_key]
@@ -563,7 +563,7 @@ class OAuthRemoteApp(object):
             )
         else:
             raise OAuthException(
-                'Unsupported access_token_method: ' %
+                'Unsupported access_token_method: %s' %
                 self.access_token_method
             )
 
